#
# spec file for package tuxpaint-config
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tuxpaint-config
Version:        0.0.22
Release:        1.3
Summary:        Configuration tool for Tux Paint
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Bitmap Editors
URL:            https://www.tuxpaint.org/
Source:         https://download.sourceforge.net/tuxpaint/tuxpaint-config/%{version}/%{name}-%{version}.tar.gz
Patch1:         tuxpaint-config-docpath.patch
Patch2:         tuxpaint-config-desktop.patch
Patch3:         tuxpaint-config-manpage.patch
BuildRequires:  fltk-devel
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libpaper-devel
BuildRequires:  libunibreak-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(pangoft2)
%if 0%{?suse_version}
BuildRequires:  fdupes
BuildRequires:  update-desktop-files
Requires:       %{name}-lang = %{version}
Recommends:     tuxpaint
%endif

%description
Tux Paint has a rich set of configuration options, controllable via
command-line options or configuration files. This configuration tool
provides a point-and-click interface for administrators to tailor
Tux Paint to suit the needs of their users.

%if 0%{?suse_version}
%{lang_package ca da el en_GB es fr it ja nl nn pt_BR pt_PT ru sk sl son sv uk zh_TW}
%endif

%prep
%autosetup -p1

%build
%make_build CFLAGS="%{optflags}" PREFIX="%{_prefix}" X11_ICON_PREFIX=%{_includedir}/X11/pixmaps/

%install
mkdir -p %{buildroot}/%{_bindir}
make PREFIX="%{buildroot}/%{_prefix}" \
     X11_ICON_PREFIX="%{buildroot}/%{_includedir}/X11/pixmaps/" \
     DOC_PREFIX="%{buildroot}/%{_defaultdocdir}/%{name}" install
install -D -m644 src/%{name}.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop

# desktop file
%if 0%{?suse_version}
%suse_update_desktop_file -n %{name}
%endif

# fix file permissions
find %{buildroot}%{_defaultdocdir}/%{name} -type f -exec chmod 644 {} \;
find %{buildroot}%{_mandir} -type f -exec chmod 644 {} \;

# reduce space
%if 0%{?suse_version}
%fdupes -s %{buildroot}
%endif

%find_lang %{name}

%files
%doc %{_defaultdocdir}/%{name}
%dir %{_includedir}/X11/pixmaps
%{_bindir}/tuxpaint-config
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/pixmaps/*.png
%{_datadir}/tuxpaint-config/
%{_includedir}/X11/pixmaps/tuxpaint-config.xpm
%{_mandir}/man1/*

%files lang -f %{name}.lang

%changelog
* Wed Jan  3 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.0.22:
  * Options for new Tux Paint 0.9.31 features:
    + "Disable 'Make Template'" added to "Simplification".
    + "Disable 'Erase' (file deletion)" added to "Simplification".
    + "UI Font" added to "Locale".
  * Bug fixes:
    + Activate "Apply" & "Reset" buttons immediately upon editing
    type-in and spinner fields; don't require focus to change
    first.
    + Make sure to remove up generated gettext '.mo' files during
    "make uninstall" process.
    + Options that may contain spaces (directory paths, like
    "savedir", or shell comamnds like "printcommand") now have
    their values wrapped in double quotes (").
    + Ensure UI Font list includes fonts bundled with Tux Paint
    but may not be visible to Tux Paint Config.
  * Other changes:
    + Option to enable debugging.
    + Improvements to debugging output options.
  * Build changes: Dropping old GNOME and KDE specific
    icon/launcher installers, having Makefile replicate more
    closely what `tuxpaint` does.
  * Updated translations.
- Rebase patches for update:
  * tuxpaint-config-docpath.patch
  * tuxpaint-config-desktop.patch
- New BuildRequires: pkgconfig(pangoft2), hicolor-icon-theme.
- Use full url for Source tarball.
* Thu Jan  6 2022 Lars Vogdt <lars@linux-schulserver.de>
- update to 0.0.18
  - please refer to /usr/share/doc/packages/tuxpaint-config/CHANGES.txt
    for a detailed list and contributors
- Needs libunibreak (libunibreak-devel) now
- Rebased all patches:
  + tuxpaint-config-desktop.patch
  + tuxpaint-config-docpath.patch
  + tuxpaint-config-manpage.patch
* Sat Oct  2 2021 Carsten Ziepke <kieltux@gmail.com>
- update to 0.0.17:
  - please refer to /usr/share/doc/packages/tuxpaint-config/CHANGES.txt
    for a detailed list and contributors
- Drop reproducible.patch, fixed upstream in 0.0.14
- Drop tuxpaint-config-missing_includes.patch, fixed upstream
- Rebase the patches
- Run spec-cleaner
* Sat Jul 14 2018 bwiedemann@suse.com
- Add reproducible.patch to override build date (boo#1047218)
* Mon Mar 12 2018 crrodriguez@opensuse.org
- remove unused xorg-x11-devel buildrequires
- respect %%optflags and do not strip main program.
* Fri Dec 26 2014 lars@linux-schulserver.de
- update to 0.0.13:
  + Added "Disable Label tool" option, to match new Tux Paint feature
  + Added options for new languages
  + Added "Accessibility" tab, with options for sticky mouse clicks,
    keyboard-based mouse movement, and on-screen keyboard
    (new features in Tux Paint)
  + Added "Joystick" tab, with options for configuring joystick controls
    (another new feature in Tux Paint)
  + Fixed bug where hitting [Cancel] in file/directory chooser dialogs
    would cause Tux Paint Config. to crash
  + Modularized some of the UI layout code
  + new translations
- refreshed all patches
- added tuxpaint-config-missing_includes.patch
- removed tuxpaint-config-de.po (upstream translation exists now)
* Mon Jul  9 2012 lars@linux-schulserver.de
- fix license to be in SPDX format
* Fri Jun 29 2012 lars@linux-schulserver.de
- added tuxpaint-config-manpage.patch to fix manpage typos
- specfile cleanup
* Sun Jul  3 2011 lars@linux-schulserver.de
- fix build on newer openSUSE distributions (fix language dirs)
* Mon Aug  3 2009 lars@linux-schulserver.de
- update to 0.0.12:
  + Added "Disable Magic controls" option
  + Added "Load all locale fonts" option
  + Added "Save Printer Configuration" option
  + Added translation files
  + Added options for "Asturian", "Shuswap" and "Songhay" languages
- split up lang package
- added german language
* Thu Oct 30 2008 lars@linux-schulserver.de
- fix desktop category
* Wed Oct  1 2008 lars@linux-schulserver.de
- update to 0.0.11:
  + fix desktop icon path
  + "Ojibwe" is the proper spelling of the language;
    changed option in TPC.
- fix desktop entry patch: prefix with X-
* Thu Sep 25 2008 lars@linux-schulserver.de
- moved to Education base repository
* Tue Mar  4 2008 lars@linux-schulserver.de
- update to 0.0.10
  - Added "Allow screensaver" option, to match new
    Tux Paint feature.
  - Added newly supported Tux Paint locales:
    + Australian English
    + Azerbaijani
    + Canadian English
    + Khmer
    + Macedonian
    + Occitan
    + Zapoteco
* Mon Jan 14 2008 lars@linux-schulserver.de
- initial package 0.0.9
